Contains high-level interface for a pull-based XML parser.
The most important type in this module is EventReader, which provides an iterator
view for events in XML document.
Structs
- Doctype
Ref - Supplement to the Doctype event (use the event if you want the full syntax)
- Error
- An XML parsing error.
- Event
Reader - A wrapper around an
std::io::Readinstance which provides pull-based XML parsing. - Events
- An iterator over XML events created from some type implementing
Read. - Parser
Config - Parser configuration structure. There are more config methods than public fileds — see methods below.
Enums
- Error
Kind - Failure reason
- Immutable
Entities Error - Returned by
add_entities() - XmlEvent
- An element of an XML input stream.
Type Aliases
- Result
- A result type yielded by
XmlReader.